@@ -8,7 +8,7 @@ sub _read {
     my ( $self, $image, $fh, $options ) = @_;
 
     if ( $image->has_sauce ) {
-        $image->render_options->{ blink_mode } = $image->sauce->flags_id ^ 1;
+        $image->render_options->{ blink_mode } = ($image->sauce->flags_id & 1) ^ 1;
     }
 
     my $width = $options->{ width } || 160;
@@ -45,7 +45,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2014 by Brian Cassidy
+Copyright 2008-2015 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
